@@ -97,8 +97,7 @@ class RoomsControl:
 				gobject.idle_add(room.entry3.grab_focus)
 				# Remove hilite
 				if name in self.frame.tray_status["hilites"]["rooms"]:
-					self.frame.tray_status["hilites"]["rooms"].remove(name)
-					self.frame.load_image(None)
+					self.frame.ClearNotification("rooms", None, name)
 
 			
 	def OnResort(self, column, column_id):
@@ -309,11 +308,18 @@ class ChatRoom(ChatRoomTab):
 	        	self.ChatScroll.get_parent().get_vadjustment().connect("value-changed", lambda *args: self.ChatScroll.queue_draw())
 	        	self.ChatScroll.get_parent().get_hadjustment().connect("value-changed", lambda *args: self.ChatScroll.queue_draw())
 
+		self.Elist = {}
 		self.encoding, m = EncodingsMenu(self.frame.np, "roomencoding", room)
+		self.EncodingStore = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
+		self.Encoding.set_size_request(100, -1)
+		self.Encoding.set_model(self.EncodingStore)
+		cell2 = gtk.CellRendererText()
+		self.Encoding.pack_start(cell2, False)
+		self.Encoding.add_attribute(cell2, 'text', 1)
 		for item in m:
-			self.Encoding.append_text(item)
-		if self.encoding in m:
-			self.Encoding.set_active(m.index(self.encoding))
+			self.Elist[item[1]] = self.EncodingStore.append([item[1], item[0] ])
+			if self.encoding == item[1]:
+				self.Encoding.set_active_iter(self.Elist[self.encoding])
 
 		self.Log.set_active(self.frame.np.config.sections["logging"]["chatrooms"])
 		
@@ -349,12 +355,12 @@ class ChatRoom(ChatRoomTab):
 	
 		self.popup_menu = popup = PopupMenu(self.frame)
 		popup.setup(
-			(_("Send _message"), popup.OnSendMessage),
+			("#" + _("Send _message"), popup.OnSendMessage, gtk.STOCK_EDIT),
 			("", None),
-			(_("Show IP a_ddress"), popup.OnShowIPaddress),
-			(_("Get user i_nfo"), popup.OnGetUserInfo),
-			(_("Brow_se files"), popup.OnBrowseUser),
-			(_("Gi_ve privileges"), popup.OnGivePrivileges),
+			("#" + _("Show IP a_ddress"), popup.OnShowIPaddress, gtk.STOCK_NETWORK),
+			("#" + _("Get user i_nfo"), popup.OnGetUserInfo, gtk.STOCK_DIALOG_INFO),
+			("#" + _("Brow_se files"), popup.OnBrowseUser, gtk.STOCK_HARDDISK),
+			("#" + _("Gi_ve privileges"), popup.OnGivePrivileges, gtk.STOCK_JUMP_TO),
 			("$" + _("_Add user to list"), popup.OnAddToList),
 			("$" + _("_Ban this user"), popup.OnBanUser),
 			("$" + _("_Ignore this user"), popup.OnIgnoreUser),
@@ -364,7 +370,10 @@ class ChatRoom(ChatRoomTab):
 		self.entry3.grab_focus()
 		self.vbox6.set_focus_child(self.entry3)
 		
-		self.logpopupmenu = PopupMenu(self.frame).setup(["Clear log", self.OnClearRoomLog])
+		self.logpopupmenu = PopupMenu(self.frame).setup(
+			("#" + _("Copy All"), self.OnCopyAllRoomLog, gtk.STOCK_COPY),
+			("#" + _("Clear log"), self.OnClearRoomLog, gtk.STOCK_CLEAR),
+		)
 		self.RoomLog.connect("button-press-event", self.OnPopupRoomLogMenu)
 		
 	def get_custom_widget(self, id, string1, string2, int1, int2):
@@ -434,8 +443,11 @@ class ChatRoom(ChatRoomTab):
 			# add hilite to trayicon
 			if self.frame.ChatNotebook.get_current_page() != self.frame.ChatNotebook.page_num(self.roomsctrl.joinedrooms[self.room].Main) or self.frame.notebook1.get_current_page() != 0:
 				if self.room not in self.frame.tray_status["hilites"]["rooms"]:
-					self.frame.tray_status["hilites"]["rooms"].append(self.room)
-					self.frame.load_image(None)
+					self.frame.Notification("rooms", msg.user, self.room)
+			#else:
+				#self.MainWindow.set_urgency_hint(False)
+				
+
 		else:
 			self.frame.ChatNotebook.request_changed(self.Main)
 			self.frame.ChatRequestIcon(0)
@@ -463,7 +475,7 @@ class ChatRoom(ChatRoomTab):
 
 	
 	CMDS = ["/alias ", "/unalias ", "/whois ", "/browse ", "/ip ", "/pm ", "/msg ", "/search ", "/usearch ", "/rsearch ",
-		"/bsearch ", "/join ", "/leave", "/add ", "/ban ", "/ignore ", "/unban ", "/unignore ", "/clear", "/part ", "/quit",
+		"/bsearch ", "/join ", "/leave", "/add ", "/buddy ", "/rem ", "/unbuddy ", "/ban ", "/ignore ", "/unban ", "/unignore ", "/clear", "/part ", "/quit",
 		"/rescan", "/tick", "/nsa", "/info"]
 
 	def OnEnter(self, widget):
@@ -540,9 +552,12 @@ class ChatRoom(ChatRoomTab):
 				self.frame.np.queue.put(slskmessages.LeaveRoom(args))
 			else:
 				self.frame.np.queue.put(slskmessages.LeaveRoom(self.room))
-		elif cmd in ["/ad", "/add"]:
+		elif cmd in ["/ad", "/add", "/buddy"]:
 			if args:
 				self.frame.userlist.AddToList(args)
+		elif cmd in ["/rem", "/unbuddy"]:
+			if args:
+				self.frame.userlist.RemoveFromList(args)
 		elif cmd == "/ban":
 			if args:
 				self.frame.BanUser(args)
@@ -566,6 +581,10 @@ class ChatRoom(ChatRoomTab):
 			self.frame.OnAway(None)
 		elif cmd in ["/q", "/quit"]:
 			self.frame.OnExit(None)
+		elif cmd == "/now":
+			np = self.frame.now.DisplayNowPlaying(None)
+			if np:
+				self.frame.np.queue.put(slskmessages.SayChatroom(self.room, np))	
 		elif cmd == "/rescan":
 			self.frame.BothRescan()
 		elif cmd  in ["/tick", "/t"]:
@@ -718,7 +737,12 @@ class ChatRoom(ChatRoomTab):
 		widget.emit_stop_by_name("button-press-event")
 		self.logpopupmenu.popup(None, None, None, event.button, event.time)
 		return True
-
+	
+	def OnCopyAllRoomLog(self, widget):
+		start, end = self.RoomLog.get_buffer().get_bounds()
+		log = self.RoomLog.get_buffer().get_text(start, end)
+		self.frame.clip.set_text(log)
+		
 	def OnClearRoomLog(self, widget):
 		self.RoomLog.get_buffer().set_text("")
 
