@@ -29,19 +29,13 @@ from about import *
 from checklatest import checklatest
 from pynicotine.config import *
 import utils
-from utils import AppendLine, ImageLabel, IconNotebook, ScrollBottom, PopupMenu, Humanize
+from utils import AppendLine, ImageLabel, IconNotebook, ScrollBottom, PopupMenu, Humanize, popupWarning
 import translux
-
+from dirchooser import ChooseFile
 from pynicotine.utils import _
-
+import nowplaying
 from entrydialog import  *
-try:
-	from pynicotine import trayicon
-	HAVE_TRAYICON = 1
-except ImportError, e:
-	print e
-	HAVE_TRAYICON = 0
-	print "Warning: Trayicon Python module not found."
+
 
 class roomlist(RoomList):
 	def __init__(self, frame):
@@ -56,17 +50,39 @@ class roomlist(RoomList):
 		widget.set_text("")
 
 class testwin(MainWindow):
-	def __init__(self, config):
+	def __init__(self, config, use_trayicon):
 		self.images = {}
 		self.clip_data = ""
 		self.configfile = config
-		
-		
+
 		self.chatrooms = None
 		
 		self.got_focus = False
+		self.importimages()
+		if sys.platform == "win32":
+				import icondata
 		config2 = Config(config)
         	config2.readConfig()
+		# For Win32 Systray 
+		if sys.platform == "win32":
+			self.icons = {}
+			for i in "hilite2", "connect", "disconnect", "away2":
+				if "icontheme"  in config2.sections["ui"]:
+					path = os.path.expanduser(os.path.join(config2.sections["ui"]["icontheme"], i +".ico"))
+					if os.path.exists(path):
+						data = open(path, 'rb')
+						s = data.read()
+						data.close()
+						self.icons[i] = s
+						del s
+						continue
+					else:
+						# default icons
+						data = getattr(icondata, i)
+				else:
+					# default icons
+					data = getattr(icondata, i)
+				self.icons[i] = data
 		for i in "empty", "away", "online", "offline", "hilite", "hilite2", "connect", "disconnect", "away2", "n":
 			loader = gtk.gdk.PixbufLoader("png")
 			if "icontheme" in config2.sections["ui"]:
@@ -89,6 +105,16 @@ class testwin(MainWindow):
 			
 			loader.close()
 			self.images[i] = loader.get_pixbuf()
+		self.trayicon = None
+		self.trayicon_module = None
+		self.TRAYICON_CREATED = 0
+		self.TRAYICON_FAILED = 0
+		self.CREATE_TRAYICON = 0
+		if use_trayicon and config2.sections["ui"]["trayicon"]:
+			self.CREATE_TRAYICON = 1
+			
+		else:
+			self.HAVE_TRAYICON = 0
 		del data
 		del config2
 		
@@ -96,13 +122,36 @@ class testwin(MainWindow):
 		self.MainWindow.set_title(_("Nicotine+") + " " + version)
 		self.MainWindow.set_icon(self.images["n"])
 		self.MainWindow.selection_add_target("PRIMARY", "STRING", 1)
+		self.MainWindow.set_geometry_hints(None, min_width=500, min_height=500)
 		self.clip = gtk.Clipboard(display=gtk.gdk.display_get_default(), selection="CLIPBOARD")
 		self.roomlist = roomlist(self)
 		
-		self.logpopupmenu = PopupMenu(self).setup([_("Clear log"), self.OnClearLogWindow])
+		self.logpopupmenu = PopupMenu(self).setup(
+			("#" + _("Copy All"), self.OnCopyAllLogWindow, gtk.STOCK_COPY),
+			("#" + _("Clear log"), self.OnClearLogWindow, gtk.STOCK_CLEAR)
+		)
+		def on_delete_event(widget, event):
+                    if self.HAVE_TRAYICON:
+                      option = Option_Box(self, title=_('Close Nicotine-Plus?'), message=_('Are you sure you wish to exit Nicotine-Plus at this time?'), option1=_("Exit"), option2=_("Send to Tray"), option3=_("Cancel") )
+                    else:
+                      option = Option_Box(self, title=_('Close Nicotine-Plus?'), message=_('Are you sure you wish to exit Nicotine-Plus at this time?'), option1=_("Exit"), option3=_("Cancel"), option2=None )
+		    if option is None:
+			pass
+		    else:
+                      if option == 2: 
+                        if self.is_mapped:
+                          self.MainWindow.unmap()
+                          self.is_mapped = 0
+                      elif option == 1:
+			if sys.platform == "win32" and self.trayicon:
+				self.trayicon.hide_icon()
+                        gtk.main_quit()
+                        return False
+                    return True
+
+                self.MainWindow.connect("delete-event",on_delete_event)
 		
-		
-		self.importimages()
+
 		self.transfermsgs = {}
 		self.transfermsgspostedtime = 0
 		self.manualdisconnect = 0
@@ -123,8 +172,8 @@ class testwin(MainWindow):
 		self.LikesList.set_model(self.likeslist)
 		self.til_popup_menu = popup = utils.PopupMenu(self)
 		popup.setup(
-			(_("_Remove this item"), self.OnRemoveThingILike),
-			(_("Re_commendations for this item"), self.OnRecommendItem),
+			("#" + _("_Remove this item"), self.OnRemoveThingILike, gtk.STOCK_CANCEL),
+			("#" + _("Re_commendations for this item"), self.OnRecommendItem, gtk.STOCK_INDEX),
 		)
 		self.LikesList.connect("button_press_event", self.OnPopupTILMenu)
 
@@ -135,7 +184,7 @@ class testwin(MainWindow):
 		cols[0].set_sort_column_id(0)
 		self.DislikesList.set_model(self.dislikeslist)
 		self.tidl_popup_menu = popup = utils.PopupMenu(self)
-		popup.setup((_("Remove this item"), self.OnRemoveThingIDislike))
+		popup.setup(("#" + _("Remove this item"), self.OnRemoveThingIDislike, gtk.STOCK_CANCEL))
 		self.DislikesList.connect("button_press_event", self.OnPopupTIDLMenu)
 
 		cols = utils.InitialiseColumns(self.RecommendationsList,
@@ -149,9 +198,9 @@ class testwin(MainWindow):
 		popup.setup(
 			("$" + _("I _like this"), self.OnLikeRecommendation),
 			("$" + _("I _don't like this"), self.OnDislikeRecommendation),
-			(_("_Recommendations for this item"), self.OnRecommendRecommendation),
+			("#" + _("_Recommendations for this item"), self.OnRecommendRecommendation, gtk.STOCK_INDEX),
 			("", None),
-			(_("_Search for this item"), self.OnRecommendSearch),
+			("#" + _("_Search for this item"), self.OnRecommendSearch, gtk.STOCK_FIND),
 		)
 		self.RecommendationsList.connect("button_press_event", self.OnPopupRMenu)
 
@@ -171,11 +220,13 @@ class testwin(MainWindow):
 		self.recommendationuserslist.set_sort_column_id(1, gtk.SORT_ASCENDING)
 		self.ru_popup_menu = popup = utils.PopupMenu(self)
 		popup.setup(
-			(_("Send _message"), popup.OnSendMessage),
+			("#" + _("Send _message"), popup.OnSendMessage, gtk.STOCK_EDIT),
+			("", None),
+			("#" + _("Show IP a_ddress"), popup.OnShowIPaddress, gtk.STOCK_NETWORK),
+			("#" + _("Get user i_nfo"), popup.OnGetUserInfo, gtk.STOCK_DIALOG_INFO),
+			("#" + _("Brow_se files"), popup.OnBrowseUser, gtk.STOCK_HARDDISK),
+			("#" + _("Gi_ve privileges"), popup.OnGivePrivileges, gtk.STOCK_JUMP_TO),
 			("", None),
-			(_("Show IP a_ddress"), popup.OnShowIPaddress),
-			(_("Get user i_nfo"), popup.OnGetUserInfo),
-			(_("Brow_se files"), popup.OnBrowseUser),
 			("$" + _("_Add user to list"), popup.OnAddToList),
 			("$" + _("_Ban this user"), popup.OnBanUser),
 			("$" + _("_Ignore this user"), popup.OnIgnoreUser),
@@ -232,6 +283,7 @@ class testwin(MainWindow):
 	        self.LogScrolledWindow.add(self.LogWindow)
 	        self.LogWindow.connect("button-press-event", self.OnPopupLogMenu)
 		self.UpdateColours()
+		
 
 	        if self.translux:
 	        	self.LogScrolledWindow.get_vadjustment().connect("value-changed", lambda *args: self.LogWindow.queue_draw())
@@ -324,17 +376,23 @@ class testwin(MainWindow):
 		
 		self.SetUserStatus(_("Offline"))
 		self.UpdateBandwidth()
+		self.UpdateTransferButtons()
 		
 		self.disconnect1.set_sensitive(0)
 		self.awayreturn1.set_sensitive(0)
 		self.check_privileges1.set_sensitive(0)
 		self.current_image=None
-		self.tray_status = {"hilites" : { "rooms": [], "private": [] }, "status": "", "last": ""}
-		if HAVE_TRAYICON:
+		self.tray_status = {"hilites" : { "rooms": [], "private": [] }, "status": "disconnect", "last": "disconnect"}
+		if self.CREATE_TRAYICON:
 			self.create_trayicon()
+		if self.HAVE_TRAYICON:
+			self.draw_trayicon()
 		if self.np.config.sections["transfers"]["rescanonstartup"]:
 			self.OnRescan()
-
+		img = gtk.Image()
+		img.set_from_pixbuf(self.images["away2"])
+		self.awayreturn1.set_image(img)
+		self.now = nowplaying.NowPlaying(self)
 		if self.np.config.needConfig():
 			self.connect1.set_sensitive(0)
 			self.rescan1.set_sensitive(0)
@@ -346,69 +404,203 @@ class testwin(MainWindow):
 	def importimages(self):
 		try:
 			import imagedata
+
 		except Exception, e:
 			print e
-		
-	def create_trayicon(self):
-		self.is_mapped = 1
-		self.trayicon = trayicon.TrayIcon("Nicotine")
-		
-		self.eventbox = gtk.EventBox()
-		img = gtk.Image()
-		self.traymenu()
-		self.load_image(None, "disconnect")
-
-		self.trayicon.add(self.eventbox)
-		self.trayicon.show_all()
-		self.eventbox.connect("button-press-event", self.OnTrayiconClicked)
 			
-	def load_image(self, image, status=None):
+	def create_trayicon(self):
+		if self.TRAYICON_FAILED:
+			return
 		try:
-			self.load_image_wrapped(image, status)
-		except:
-			print "Error changing Trayicon's icon, attempting to recreate it."
-			try:
-				self.create_trayicon()
-			except:
-				print "Trayicon failed to load"
+		        if sys.platform == "win32":
+				import systraywin32
+				self.trayicon_module = systraywin32
+			else:
+			        from pynicotine import trayicon
+			        self.trayicon_module = trayicon
+			self.HAVE_TRAYICON = 1
+			self.TRAYICON_FAILED = 0
+		except ImportError, error:
+			self.TRAYICON_FAILED = 1
+			self.HAVE_TRAYICON = 0
+			if sys.platform == "win32":
+				print "Note: The systraywin32.py Python file failed to load properly because: %s. You may require pywin32. Get a version that matches your version of Python from here:\nhttp://sourceforge.net/project/showfiles.php?group_id=78018 " % error
+				self.logMessage("Note: The systraywin32.py Python file failed to load properly because: %s. You may require pywin32. Get a version that matches your version of Python from here:\nhttp://sourceforge.net/project/showfiles.php?group_id=78018 " % error, "TrayIcon")
+			else:
+				print "Note: Trayicon Python module was not found in the pynicotine directory: %s" % error
+				self.logMessage("Note: Trayicon Python module was not found in the pynicotine directory: %s." % error, "TrayIcon")
+			
+	def destroy_trayicon(self):
+		if not self.TRAYICON_CREATED:
+			return
+		self.TRAYICON_CREATED = 0
+		self.HAVE_TRAYICON = 0
+		self.current_image = None
+		
+		if sys.platform != "win32":
+			self.eventbox.destroy()
+			self.trayicon.destroy()
+		else:
+			self.tray_status["last"] = ""
+			self.trayicon.hide_icon()
+		
+		self.tray_popup_menu.destroy()
+
+		
+	def draw_trayicon(self):
+		if not self.HAVE_TRAYICON or self.trayicon_module == None or  self.TRAYICON_CREATED:
+			return
+		self.TRAYICON_CREATED = 1
+		self.is_mapped = 1
+		self.traymenu()
+		if sys.platform == "win32":
+			if not self.trayicon:
+				self.trayicon = self.trayicon_module.TrayIcon("Nicotine", self)
+			self.trayicon.show_icon()
+			
+		else:
+			self.trayicon = self.trayicon_module.TrayIcon("Nicotine")
+			self.trayicon.show_all()
+		if sys.platform != "win32":
+			self.eventbox = gtk.EventBox()
+		self.load_image(self.tray_status["status"])
+
+		if sys.platform != "win32":
+			self.trayicon.add(self.eventbox)
+			self.eventbox.connect("button-press-event", self.OnTrayiconClicked)
+			self.trayicon.show_all()
+		
+	def Notification(self, location, user, room=None):
+		hilites = self.tray_status["hilites"]
+		if location == "rooms" and room != None and user != None:
+			if room not in hilites["rooms"]:
+				hilites["rooms"].append(room)
+				self.sound("room_nick", user, place=room)
+				self.load_image()
+				#self.MainWindow.set_urgency_hint(True)
+		if location == "private":
+			if user in hilites[location]:
+				hilites[location].remove(user)
+				hilites[location].append(user)
+			if user not in hilites[location]: 
+				hilites[location].append(user)
+				self.sound(location, user)
+				self.load_image()
+				#self.MainWindow.set_urgency_hint(True)
+		self.TitleNotification(user)
+		
+	def ClearNotification(self, location, user, room=None):
+		if location == "rooms" and room != None:
+			if room in self.tray_status["hilites"]["rooms"]:
+				self.tray_status["hilites"]["rooms"].remove(room)
+		if location == "private":	
+			if user in self.tray_status["hilites"]["private"]: 
+				self.tray_status["hilites"]["private"].remove(user)
+		self.TitleNotification(user)
+		self.load_image()
+		
+	def TitleNotification(self, user=None):
+		if self.tray_status["hilites"]["rooms"] == [] and self.tray_status["hilites"]["private"] == []:
+			# Reset Title
+			if self.MainWindow.get_title() != _("Nicotine+") + " " + version:  
+				self.MainWindow.set_title(_("Nicotine+") + " " + version)
+		else:
+			# Private Chats have a higher priority
+			if len(self.tray_status["hilites"]["private"]) > 0:
+				user = self.tray_status["hilites"]["private"][-1]
+				self.MainWindow.set_title(_("Nicotine+") + " " + version+ " :: " +  _("Private Message from %s" % user) )
+			# Allow for the possibility the username is not available
+			elif len(self.tray_status["hilites"]["rooms"]) > 0:
+				room = self.tray_status["hilites"]["rooms"][-1]
+				if user == None:
+					self.MainWindow.set_title(_("Nicotine+") + " " + version+ " :: " +  _("You've been mentioned in the %s room" % (room) ) )
+				else:
+					self.MainWindow.set_title(_("Nicotine+") + " " + version+ " :: " +  _("%s mentioned you in the %s room" % (user, room) ) )
 				
-	def load_image_wrapped(self, image, status=None):
-	
+	def load_image(self, status=None):
+		# Abort if Trayicon module wasn't loaded
+		if not self.HAVE_TRAYICON or self.trayicon_module == None or not self.TRAYICON_CREATED:
+			return
 		try:
-			# Abort if Trayicon module wasn't loaded
-			if not HAVE_TRAYICON:
-				return
 			if status != None:
 				self.tray_status["status"] = status
 			# Check for hilites, and display hilite icon if there is a room or private hilite
 			if self.tray_status["hilites"]["rooms"] == [] and self.tray_status["hilites"]["private"] == []:
-				icon = image
-			else:
-				icon = "hilite2"
-			if icon == None:
 				# If there is no hilite, display the status
 				icon = self.tray_status["status"]
+			else:
+				icon = "hilite2"
+
 			if icon != self.tray_status["last"]:
 				self.tray_status["last"] = icon
+
+			if sys.platform == "win32":
+				# For Win32 Systray 
+				self.trayicon.set_img(icon)
 			else:
-				# If the icon hasn't changed since the last time, do nothing
-				return
-			self.eventbox.hide()
-			if self.current_image != None:
-				self.eventbox.remove(self.current_image)
+				# For X11 Systray 
+				self.eventbox.hide()
+				if self.current_image != None:
+					self.eventbox.remove(self.current_image)
 			
-			img = gtk.Image()
-			img.set_from_pixbuf(self.images[icon])
+				img = gtk.Image()
+				img.set_from_pixbuf(self.images[icon])
+				img.show()
 
-			img.show()
-
-			self.current_image = img
-
-			self.eventbox.add(self.current_image)
-			self.eventbox.show()
+				self.current_image = img
+				self.eventbox.add(self.current_image)
+				self.eventbox.show()
 		except Exception,e:
-			print "ERROR: load_image_wrapped", e
+			print "ERROR: load_image", e
+			
+	def sound(self, message, user, place=None):
+		if sys.platform == "win32":
+			return
+		if "soundenabled" in self.np.config.sections["ui"]:
+			if not self.np.config.sections["ui"]["soundenabled"]:
+				return
+		else: return
+		if "speechenabled" in self.np.config.sections["ui"]:
+			if self.np.config.sections["ui"]["speechenabled"]:
+				if message == "room_nick" and place is not None:
+					os.system("flite -t \"%s, the user, %s has mentioned your name in the room, %s.\" &" %(self.np.config.sections[ "server"]["login"], user, place) )
+				elif message == "private":
+					os.system("flite -t \"%s, you have recieved a private message from %s.\" &" %(self.np.config.sections["server"]["login"], user ) )
+				return
+		path = None
+		exists = 0
+		if message == "private":
+			soundtitle = "private"
+		elif message == "room_nick":
+			soundtitle = "room_nick"
+			
+		if "soundtheme" in self.np.config.sections["ui"]:
+			path = os.path.expanduser(os.path.join(self.np.config.sections["ui"]["soundtheme"], "%s.ogg" % soundtitle))
+			if os.path.exists(path): exists = 1
+			else: path = None	
+		if not exists:
+			path = "%s/share/nicotine/sounds/default/%s.ogg" %(sys.prefix, soundtitle)
+			if os.path.exists(path): exists = 1
+			else: path = None
+		if not exists:
+			path = "sounds/default/%s.ogg" % soundtitle
+			if os.path.exists(path): exists = 1
+			else: path = None
+		if path != None and exists:
+			if "soundcommand" in self.np.config.sections["ui"]:
+				os.system("%s %s &" % ( self.np.config.sections["ui"]["soundcommand"], path))
 	
+	def download_large_folder(self, username, folder, files, numfiles, msg):
+		gtk.gdk.threads_enter()
+		
+		
+		option = Option_Box(self, title=_('Download %i files?' %numfiles), message=_("Are you sure you wish to download %i files from %s's directory %s?" %( numfiles, username, folder ) ), option1=_("Ok"), option3=_("Cancel"), option2=None )
+		gtk.gdk.threads_leave()
+
+		if option == 1:
+			self.np.transfers.FolderContentsResponse(msg)
+			
+		
 	def OnGetUserInfo(self, widget):
 		text = self.UserinfoEntry.get_text()
 		if not text:
@@ -422,7 +614,45 @@ class testwin(MainWindow):
 			return
 		self.BrowseUser(text)
 		self.SharesEntry.set_text("")
-
+	
+	def OnLoadFromDisk(self, widget):
+		configdir, config = os.path.split(self.np.config.filename)
+		sharesdir = os.path.abspath(configdir+os.sep+"usershares"+os.sep)
+		try:
+			if not os.path.exists(sharesdir):
+				os.mkdir(sharesdir)
+		except Exception, msg:
+			error = _("Can't create directory '%s', reported error: %s" % (sharesdir, msg))
+			print error
+			self.logMessage(error)
+		shares = ChooseFile(self.MainWindow.get_toplevel(), sharesdir)
+		if shares is None:
+			return
+		for share in shares: # iterate over selected files
+			share1 = share
+			break
+		try:
+			
+			import pickle, bz2
+			sharefile = bz2.BZ2File(share1)
+			list1 = pickle.load(sharefile)
+			sharefile.close()
+			if not isinstance(list1, dict):
+				raise TypeError, "Bad data in file %s" % share1
+			username = share1.split(os.sep)[-1]
+			self.userbrowse.InitWindow(username, [])
+			if username in self.userbrowse.users:
+				self.userbrowse.users[username].LoadShares(username, list1)
+		except Exception, msg:
+			error = _("Loading Shares from disk failed: %s" % msg)
+			self.logMessage(error)
+			print error
+			
+	def OnNowPlayingConfigure(self, widget):
+		
+		self.now.NowPlaying.show()
+		
+		
 	def OnGetPrivateChat(self, widget):
 		text = self.PrivateChatEntry.get_text()
 		if not text:
@@ -432,8 +662,8 @@ class testwin(MainWindow):
 		
 	def OnGetAUsersInfo(self, widget, prefix = ""):
 		# popup
-		user = input_box(self, title='Nicotine+: Get User Info',
-		message='Enter the User whose User Info you wish to recieve:',
+		user = input_box(self, title=_('Nicotine+: Get User Info'),
+		message=_('Enter the User whose User Info you wish to recieve:'),
 		default_text='')
 		if user is None:
 			pass
@@ -441,8 +671,8 @@ class testwin(MainWindow):
 			self.LocalUserInfoRequest(user)
 			
 	def OnGetAUsersIP(self, widget, prefix = ""):
-		user = input_box(self, title="Nicotine+: Get A User's IP",
-		message='Enter the User whose IP Address you wish to recieve:',
+		user = input_box(self, title=_("Nicotine+: Get A User's IP"),
+		message=_('Enter the User whose IP Address you wish to recieve:'),
 		default_text='')
 		if user is None:
 			pass
@@ -451,8 +681,8 @@ class testwin(MainWindow):
 # 			self.np.ProcessRequestToPeer(user, slskmessages.UserInfoRequest(None), self.userinfo)
 			
 	def OnGetAUsersShares(self, widget, prefix = ""):
-		user = input_box(self, title="Nicotine+: Get A User's Shares List",
-		message='Enter the User whose Shares List you wish to recieve:',
+		user = input_box(self, title=_("Nicotine+: Get A User's Shares List"),
+		message=_('Enter the User whose Shares List you wish to recieve:'),
 		default_text='')
 		if user is None:
 			pass
@@ -461,65 +691,39 @@ class testwin(MainWindow):
 			
 	def traymenu(self):
 		try:
-			file_menu = gtk.Menu()
-			connect_menu = gtk.Menu()
-			
-			quit_item = gtk.MenuItem("Quit")
-			quit_item.connect_object("activate", self.OnExit, "file.quit")
-			quit_item.show()
 
-			ip_item = gtk.MenuItem("Lookup A User's IP")
-			ip_item.connect_object("activate", self.OnGetAUsersIP, "file.ip")
-			ip_item.show()
-			
-			userinfo_item = gtk.MenuItem("Lookup A User's Info")
-			userinfo_item.connect_object("activate", self.OnGetAUsersInfo, "file.userinfo")
-			userinfo_item.show()
-			
-			shares_item = gtk.MenuItem("Lookup A User's Shares")
-			shares_item.connect_object("activate", self.OnGetAUsersShares, "file.usershares")
-			shares_item.show()
-			
-			hide_item = gtk.MenuItem("Hide / Unhide Nicotine")
-			hide_item.connect_object("activate", self.HideUnhideWindow, "file.hide")
-			hide_item.show()
-			
-			away_item = gtk.MenuItem("Toggle Away")
-			away_item.connect_object("activate", self.OnAway, "file.away")
-			away_item.add_accelerator("activate", self.accel_group, gtk.gdk.keyval_from_name("A"), gtk.gdk.MOD1_MASK, gtk.ACCEL_VISIBLE)
-			away_item.show()
-			
-			settings_item = gtk.MenuItem("Settings")
-			settings_item.connect_object("activate", self.OnSettings, "settings")
-			settings_item.show()
-			
-			connect_item = gtk.MenuItem("Connect")
-			connect_item.connect_object("activate", self.OnConnect, None)
-			connect_item.show()
-			
-			disconnect_item = gtk.MenuItem("Disconnect")
-			disconnect_item.connect_object("activate", self.OnDisconnect, "disconnect")
-			disconnect_item.show()
-			
-			connect_menu.append(connect_item)
-			connect_menu.append(disconnect_item)
-					
-			server_menu = gtk.MenuItem("Server")
-			server_menu.show()
-			server_menu.set_submenu(connect_menu)
-			file_menu.append(hide_item)
-			file_menu.append(server_menu)
-			file_menu.append(settings_item)
-			file_menu.append(ip_item)
-			file_menu.append(userinfo_item)
-			file_menu.append(shares_item)
-			file_menu.append(away_item)
-			file_menu.append(quit_item)
-			self.tray_menu = file_menu
-			
+			self.tray_popup_menu_server = popup0 = PopupMenu(self)
+			popup0.setup(
+				("#" + _("Connect"), self.OnConnect, gtk.STOCK_CONNECT),
+				("#" + _("Disconnect"), self.OnDisconnect, gtk.STOCK_DISCONNECT),
+			)
+			self.tray_popup_menu = popup = PopupMenu(self)
+			popup.setup(
+				("#" + _("Hide / Unhide Nicotine"), self.HideUnhideWindow, gtk.STOCK_GOTO_BOTTOM),
+				(1, _("Server"), self.tray_popup_menu_server, self.OnPopupServer),
+				("#" + _("Settings"), self.OnSettings, gtk.STOCK_PREFERENCES),
+				("#" + _("Lookup a User's IP"), self.OnGetAUsersIP, gtk.STOCK_NETWORK),
+				("#" + _("Lookup a User's Info"), self.OnGetAUsersInfo, gtk.STOCK_DIALOG_INFO),
+				("#" + _("Lookup a User's Shares"), self.OnGetAUsersShares, gtk.STOCK_HARDDISK),
+				("%" + _("Toggle Away"), self.OnAway, self.images["away2"] ),
+				("#" + _("Quit"), self.OnExit, gtk.STOCK_QUIT),
+			)
+		
 		except Exception,e:
 			print "ERROR: tray menu", e
 			
+	def OnPopupServer(self, widget):
+		items = self.tray_popup_menu_server.get_children()
+		
+		
+		if self.tray_status["status"] == "disconnect":
+			items[0].set_sensitive(True)
+			items[1].set_sensitive(False)
+		else:
+			items[0].set_sensitive(False)
+			items[1].set_sensitive(True)
+		return
+		
 	def button_press(self, widget, event):
 		try:
 
@@ -547,12 +751,24 @@ class testwin(MainWindow):
 		(w, h) = self.trayicon.get_size()
 		if event.x < 0 or event.y < 0 or event.x >= w or event.y >= h:
 			return
-# 		print event.button
+
 		if event.button == 1:
 			self.HideUnhideWindow(None)
 		else:
+			items = self.tray_popup_menu.get_children()
+			if self.tray_status["status"] == "disconnect":
+				items[3].set_sensitive(False)
+				items[4].set_sensitive(False)
+				items[5].set_sensitive(False)
+				items[6].set_sensitive(False)
+			else:
+				
+				items[3].set_sensitive(True)
+				items[4].set_sensitive(True)
+				items[5].set_sensitive(True)
+				items[6].set_sensitive(True)
 			if event.type == gtk.gdk.BUTTON_PRESS:
-				self.tray_menu.popup(None, None, None, event.button, event.time)
+				self.tray_popup_menu.popup(None, None, None, event.button, event.time)
 				return True
 			return False
 				
@@ -675,11 +891,16 @@ class testwin(MainWindow):
 	            self.np.transfers.AbortTransfers()
 		self.np.config.writeConfig()
 		self.np.protothread.abort()
+		if sys.platform == "win32":
+			if self.trayicon:
+				self.trayicon.hide_icon()
 		gtk.main_quit()
 		
 	def OnConnect(self, widget):
 		self.connect1.set_sensitive(0)
 		self.disconnect1.set_sensitive(1)
+		self.tray_status["status"] = "connect"
+		self.load_image()
 		if self.np.serverconn is not None:
 			return
 		if widget != -1:
@@ -687,7 +908,7 @@ class testwin(MainWindow):
 				self.np.queue.get(0)
 		self.SetUserStatus("...")
 		server = self.np.config.sections["server"]["server"]
-		self.SetStatusText("Connecting to %s:%s" %(server[0],server[1]))
+		self.SetStatusText(_("Connecting to %s:%s") %(server[0],server[1]) )
 		self.np.queue.put(slskmessages.ServerConn(None, server))
 		if self.np.servertimer is not None:
 			self.np.servertimer.cancel()
@@ -718,9 +939,11 @@ class testwin(MainWindow):
 		self.check_privileges1.set_sensitive(0)
 		
 		self.SetUserStatus(_("Offline"))
-		self.load_image(None, "disconnect")
+		self.tray_status["status"] = "disconnect"
+		self.load_image()
 		self.searches.interval = 0
 		self.chatrooms.ConnClose()
+		self.privatechats.ConnClose()
 		self.searches.ConnClose()
 		self.uploads.ConnClose()
 		self.downloads.ConnClose()
@@ -731,7 +954,8 @@ class testwin(MainWindow):
 		self.disconnect1.set_sensitive(0)
 		
 		self.SetUserStatus(_("Offline"))
-		self.load_image(None, "disconnect")
+		self.tray_status["status"] = "disconnect"
+		self.load_image()
 		
 	def SetUserStatus(self, status):
 		self.UserStatus.pop(self.user_context_id)
@@ -740,7 +964,8 @@ class testwin(MainWindow):
 	def InitInterface(self, msg):
 		if self.away == 0:
 			self.SetUserStatus(_("Online"))
-			self.load_image(None, "connect")
+			self.tray_status["status"] = "connect"
+			self.load_image()
 			autoaway = self.np.config.sections["server"]["autoaway"]
 			if autoaway > 0:
 				self.awaytimer = gobject.timeout_add(1000*60*autoaway, self.OnAutoAway)
@@ -748,7 +973,8 @@ class testwin(MainWindow):
 				self.awaytimer = None
 		else:
 			self.SetUserStatus(_("Away"))
-			self.load_image(None, "away2")
+			self.tray_status["status"] = "away2"
+			self.load_image()
 		
 		self.awayreturn1.set_sensitive(1)
 		self.check_privileges1.set_sensitive(1)
@@ -775,21 +1001,24 @@ class testwin(MainWindow):
 		self.away = (self.away+1) % 2
 		if self.away == 0:
 			self.SetUserStatus(_("Online"))
-			self.load_image(None, "connect")
+			self.tray_status["status"] = "connect"
+			self.load_image()
 		else:
 			self.SetUserStatus(_("Away"))
-			self.load_image(None, "away2")
+			self.tray_status["status"] = "away2"
+			self.load_image()
 		self.np.queue.put(slskmessages.SetStatus(self.away and 1 or 2))
-		if HAVE_TRAYICON:
-			pass
-			
+
 		
 	def OnExit(self, widget):
 		self.MainWindow.destroy()
 	
 	def OnSearch(self, widget):
 		self.searches.OnSearch()
-
+		
+	def OnClearSearchHistory(self, widget):
+		self.searches.OnClearSearchHistory()
+		
 	def ChatRequestIcon(self, status = 0):
 		if status == 1 and not self.got_focus:
 			self.MainWindow.set_icon(self.images["hilite2"])
@@ -798,13 +1027,14 @@ class testwin(MainWindow):
 		if status == 0:
 			if self.ChatTabLabel.get_image() == self.images["hilite"]:
 				return
-		self.ChatTabLabel.set_image(status == 1 and self.images["hilite"] or self.images["hilite"])
+		self.ChatTabLabel.set_image(status == 1 and self.images["hilite"] or self.images["online"])
 
 	def RequestIcon(self, tablabel):
 		if tablabel == self.PrivateChatTabLabel and not self.got_focus:
 			self.MainWindow.set_icon(self.images["hilite2"])
 		if self.current_tab != tablabel:
 			tablabel.set_image(self.images["hilite"])
+			
 		
 	def OnSwitchPage(self, notebook, page, page_nr):
 		l = [self.ChatTabLabel, self.PrivateChatTabLabel, None, None, self.SearchTabLabel, self.UserInfoTabLabel, self.UserBrowseTabLabel, None, None][page_nr]
@@ -962,11 +1192,20 @@ class testwin(MainWindow):
 		self.np.queue.put(slskmessages.SetUploadLimit(uselimit,uploadlimit,limitby))
 
 		self.np.config.writeConfig()
+		if not self.np.config.sections["ui"]["trayicon"] and self.HAVE_TRAYICON:
+			self.destroy_trayicon()
+		elif self.np.config.sections["ui"]["trayicon"] and not self.HAVE_TRAYICON:
+			if self.trayicon_module == None and not self.TRAYICON_CREATED:
+				self.create_trayicon()
+			else:
+				self.HAVE_TRAYICON = 1
+				
+			self.draw_trayicon()
 
 		self.chatrooms.roomsctrl.UpdateColours()
 		self.privatechats.UpdateColours()
 		self.UpdateColours()
-		
+		self.UpdateTransferButtons()
 		if needrescan:
 			self.needrescan = 1
 		
@@ -981,7 +1220,49 @@ class testwin(MainWindow):
 		else:
 			if self.np.transfers is None:
 				self.connect1.set_sensitive(1)
-
+				
+	def UpdateTransferButtons(self):
+		if self.np.config.sections["transfers"]["enabletransferbuttons"]:
+			self.DownloadButtons.show()
+			self.UploadButtons.show()
+		else:
+			self.UploadButtons.hide()
+			self.DownloadButtons.hide()
+			
+	def OnNicotineGuide(self, widget):
+		file = "doc/NicotinePlusGuide.html" 
+		if os.path.exists(file):
+			url = "file://%s/%s" % (os.environ["PWD"], file)
+			self.OpenUrl(url)
+		else:
+			file = "%s/share/nicotine/documentation/NicotinePlusGuide.html" % sys.prefix
+			if os.path.exists(file):
+				url = "file://%s" % file
+				self.OpenUrl(url)
+			else:
+				popupWarning(None, _("Cannot Find Guide"), _("The Nicotine Offline Guide ( NicotinePlusGuide.html ) was not found in either the following directories:\n\n<u>%s/doc/\n</u><b>and</b>\n<u>%s/share/nicotine/documentation/</u>\n\nEither install Nicotine-Plus, or start from inside the Nicotine-Plus source directory." % (os.environ["PWD"], sys.prefix ) ) )
+		
+	def OnSourceForgeProject(self, widget):
+		url = "http://sourceforge.net/projects/nicotine-plus/"
+		self.OpenUrl(url)
+		
+	def OnTrac(self, widget):
+		url = "http://nicotine-plus.org/"
+		self.OpenUrl(url)
+		
+	def OpenUrl(self, url):
+		if utils.PROTOCOL_HANDLERS.has_key("http"):
+			if utils.PROTOCOL_HANDLERS["http"].__class__ is utils.types.MethodType:
+				utils.PROTOCOL_HANDLERS["http"](url)
+			else:
+				cmd = utils.PROTOCOL_HANDLERS["http"] % url
+				os.system(cmd)
+		else:
+			try:
+				import gnome.vfs
+				gnome.url_show(url)
+			except Exception, e:
+				pass
 	def OnAbout(self, widget):
 		dlg = AboutDialog(self.MainWindow)
 		dlg.run()
@@ -1078,9 +1359,13 @@ class testwin(MainWindow):
 		if user == self.np.config.sections["server"]["login"]:
 			try:
 				if self.np.config.sections["userinfo"]["pic"] != "":
-					if os.path.exists(self.np.config.sections["userinfo"]["pic"]):
+					if sys.platform == "win32":
+						userpic = u"%s" % self.np.config.sections["userinfo"]["pic"]
+					else:
+						userpic = self.np.config.sections["userinfo"]["pic"]
+					if os.path.exists(userpic):
 						has_pic = True
-						f=open(self.np.config.sections["userinfo"]["pic"],'r')
+						f=open(userpic,'rb')
 						pic = f.read()
 						f.close()
 					else:
@@ -1140,6 +1425,11 @@ class testwin(MainWindow):
 		self.logpopupmenu.popup(None, None, None, event.button, event.time)
 		return True
 
+	def OnCopyAllLogWindow(self, widget):
+		start, end = self.LogWindow.get_buffer().get_bounds()
+		log = self.LogWindow.get_buffer().get_text(start, end)
+		self.clip.set_text(log)
+		
 	def OnClearLogWindow(self, widget):
 		self.LogWindow.get_buffer().set_text("")
 
@@ -1379,8 +1669,8 @@ class testwin(MainWindow):
 	def OnUserList(self, widget):
 		self.notebook1.set_current_page(8)
 class MainApp:
-	def __init__(self, config):
-		self.frame = testwin(config)
+	def __init__(self, config, trayicon):
+		self.frame = testwin(config, trayicon)
 	
 	def MainLoop(self):
 		signal.signal(signal.SIGINT, signal.SIG_IGN)
