@@ -29,9 +29,12 @@ class Searches:
 		#frame.combo1.disable_activate()
 		
 		items = self.frame.np.config.sections["searches"]["history"]
+		templist = []
 		for i in items:
+			if i not in templist:
+				templist.append(i)
+		for i in templist:
 			self.frame.combo1.append_text(i)
-		#frame.combo1.set_popdown_strings([""] + items)
 		
 	def SetInterval(self, msg):
 		self.interval = 1000
@@ -70,22 +73,18 @@ class Searches:
 		
 		return True
 	
+	def OnClearSearchHistory(self):
+		self.frame.SearchEntry.set_text("")
+		self.frame.np.config.sections["searches"]["history"] = []
+		self.frame.np.config.writeConfig()
+		self.frame.combo1.get_model().clear()
+	
 	def OnSearch(self):
 		text = self.frame.SearchEntry.get_text().strip()
 		self.frame.SearchEntry.set_text("")
 		if not text:
 			return
-		
-		s = self.frame.np.config.sections["searches"]["history"]
-		if text in s:
-			s.remove(text)
-		s.insert(0, text)
-		del s[15:]
-		self.frame.np.config.writeConfig()
-		#self.frame.combo1.set_popdown_strings([""] + s)
-		for i in s:
-			self.frame.combo1.append_text(i)
-			
+
 		if self.frame.GlobalRadio.get_active():
 			mode = 0
 		elif self.frame.RoomsRadio.get_active():
@@ -95,6 +94,22 @@ class Searches:
 		self.DoSearch(text, mode)
 		
 	def DoSearch(self, text, mode, users = []):
+		items = self.frame.np.config.sections["searches"]["history"]
+		if text in items:
+			items.remove(text)
+		items.insert(0, text)
+		# Clear old items
+		del items[15:]
+		self.frame.np.config.writeConfig()
+		# Repopulate the combo list
+		self.frame.combo1.get_model().clear()
+		templist = []
+		for i in items:
+			if i not in templist:
+				templist.append(i)
+		for i in templist:
+			self.frame.combo1.append_text(i)
+			
 		self.CreateTab(self.searchid, text, mode)
 		text = self.frame.np.encode(text)
 		if mode == 0:
@@ -128,9 +143,9 @@ class Searches:
 		tab = Search(self, text, id, mode, remember)
 
 		if mode:
-			label = "(" + ("", _("Rooms"), _("Buddies"), _("User"))[mode] + ") " + text
+			label = "(" + ("", _("Rooms"), _("Buddies"), _("User"))[mode] + ") " + text[:15]
 		else:
-			label = text
+			label = text[:20]
 		self.frame.SearchNotebook.append_page(tab.vbox7, label, tab.OnCloseIgnore)
 
 		search = [id, text, tab, mode, remember]
@@ -338,6 +353,7 @@ class Search(SearchTab):
 		self.mode = mode
 		self.remember = remember
 		self.users = []
+		self.QueryLabel.set_text(text)
 
 		self.resultsmodel = SearchTreeModel()
 
@@ -391,18 +407,18 @@ class Search(SearchTab):
 		
 		self.popup_menu = popup = PopupMenu(self.frame)
 		popup.setup(
-			(_("_Download file(s)"), self.OnDownloadFiles),
-			(_("Download file(s) _to..."), self.OnDownloadFilesTo),
-			(_("Download containing _folder(s)"), self.OnDownloadFolders),
+			("#" + _("_Download file(s)"), self.OnDownloadFiles, gtk.STOCK_GO_DOWN),
+			("#" + _("Download file(s) _to..."), self.OnDownloadFilesTo, gtk.STOCK_GO_DOWN),
+			("#" + _("Download containing _folder(s)"), self.OnDownloadFolders, gtk.STOCK_GO_DOWN),
 			("", None),
-			(_("Copy _URL"), self.OnCopyURL),
-			(_("Copy folder URL"), self.OnCopyDirURL),
+			("#" + _("Copy _URL"), self.OnCopyURL, gtk.STOCK_COPY),
+			("#" + _("Copy folder URL"), self.OnCopyDirURL, gtk.STOCK_COPY),
 			("", None),
-			(_("Send _message"), popup.OnSendMessage),
-			(_("Show IP a_ddress"), popup.OnShowIPaddress),
-			(_("Get user i_nfo"), popup.OnGetUserInfo),
-			(_("Brow_se files"), popup.OnBrowseUser),
-			(_("Gi_ve privileges"), popup.OnGivePrivileges),
+			("#" + _("Send _message"), popup.OnSendMessage, gtk.STOCK_EDIT),
+			("#" + _("Show IP a_ddress"), popup.OnShowIPaddress, gtk.STOCK_NETWORK),
+			("#" + _("Get user i_nfo"), popup.OnGetUserInfo, gtk.STOCK_DIALOG_INFO),
+			("#" + _("Brow_se files"), popup.OnBrowseUser, gtk.STOCK_HARDDISK),
+			("#" + _("Gi_ve privileges"), popup.OnGivePrivileges, gtk.STOCK_JUMP_TO),
 			("$" + _("_Add user to list"), popup.OnAddToList),
 			("$" + _("_Ban this user"), popup.OnBanUser),
 			("$" + _("_Ignore this user"), popup.OnIgnoreUser),
@@ -547,7 +563,9 @@ class Search(SearchTab):
 		dir = ChooseDir(self.frame.MainWindow, self.frame.np.config.sections["transfers"]["downloaddir"])
 		if dir is None:
 			return
-		self.OnDownloadFiles(widget, dir)
+		for dirs in dir:
+			self.OnDownloadFiles(widget, dirs)
+			break
 	
 	def OnDownloadFolders(self, widget):
 		folders = []
@@ -589,10 +607,11 @@ class Search(SearchTab):
 
 	def OnClose(self, widget):
 		self.searches.RemoveTab(self)
+		self.OnCloseIgnore(widget)
 
 	def OnCloseIgnore(self, widget):
 		self.OnIgnore(self.button2)
-		self.OnClose(widget)
+		self.searches.RemoveTab(self)
 
 	def OnToggleRemember(self, widget):
 		self.remember = widget.get_active()
