@@ -5,7 +5,7 @@ import gobject
 import settings_glade
 import locale
 
-from dirchooser import ChooseDir
+from dirchooser import *
 from utils import InputDialog, InitialiseColumns, recode, recode2, popupWarning
 import os, sys
 win32 = sys.platform.startswith("win")
@@ -19,8 +19,15 @@ class ServerFrame(settings_glade.ServerFrame):
 	def __init__(self, encodings):
 		settings_glade.ServerFrame.__init__(self, False)
 		self.Server.append_text("server.slsknet.org:2240")
-		for code in encodings:
-			self.Encoding.append_text(code)
+
+		self.Elist = {}
+		self.EncodingStore = gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
+		self.Encoding.set_model(self.EncodingStore)
+		cell2 = gtk.CellRendererText()
+		self.Encoding.pack_start(cell2, False)
+		self.Encoding.add_attribute(cell2, 'text', 1)
+		for item in encodings:
+			self.Elist[item[1]] = self.EncodingStore.append([item[1], item[0] ])
 
 	def SetSettings(self, config):
 		server = config["server"]
@@ -49,7 +56,8 @@ class ServerFrame(settings_glade.ServerFrame):
 			server = tuple(server)
 		except:
 			server = None
-
+		if str(self.Login.get_text()) == "None":
+			popupWarning(None, _("Warning: Bad Username"), _("Username None is not a good password, please pick another.") )
 		try:
 			firstport = int(self.FirstPort.get_text())
 			lastport = int(self.LastPort.get_text())
@@ -103,7 +111,7 @@ class SharesFrame(settings_glade.SharesFrame):
 			self.DownloadDir.set_text(recode(transfers["downloaddir"]))
 		if transfers["sharedownloaddir"] is not None:
 			if homedir == transfers["downloaddir"] and transfers["sharedownloaddir"]:
-				popupWarning(None, "Warning","Security Risk: you should not share your %s directory!" %place)
+				popupWarning(None, _("Warning"),_("Security Risk: you should not share your %s directory!" %place))
 			self.ShareDownloadDir.set_active(transfers["sharedownloaddir"])
 		self.shareslist.clear()
 		self.bshareslist.clear()
@@ -111,13 +119,13 @@ class SharesFrame(settings_glade.SharesFrame):
 		if transfers["shared"] is not None:
 			for share in transfers["shared"]:
 				if homedir == share:
-					popupWarning(None, "Warning","Security Risk: you should not share your %s directory!" %place)
+					popupWarning(None, _("Warning"),_("Security Risk: you should not share your %s directory!" %place))
 				self.shareslist.append([recode(share), share])
 			self.shareddirs = transfers["shared"][:]
 		if transfers["buddyshared"] is not None:
 			for share in transfers["buddyshared"]:
 				if homedir == share:
-					popupWarning(None, "Warning","Security Risk: you should not share your %s directory!" %place)
+					popupWarning(None, _("Warning"),_("Security Risk: you should not share your %s directory!" %place))
 				self.bshareslist.append([recode(share), share])
 			self.bshareddirs = transfers["buddyshared"][:]
 		if transfers["rescanonstartup"] is not None:
@@ -139,6 +147,7 @@ class SharesFrame(settings_glade.SharesFrame):
 				"enablebuddyshares": self.enableBuddyShares.get_active(),
 			}
 		}
+
 	def OnEnabledBuddySharesToggled(self, widget):
 		sensitive = widget.get_active()
 		self.BuddyShares.set_sensitive(sensitive)
@@ -149,17 +158,16 @@ class SharesFrame(settings_glade.SharesFrame):
 		return self.needrescan
 	
 	def OnChooseIncompleteDir(self, widget):
-		dir = ChooseDir(self.Main.get_toplevel(), self.IncompleteDir.get_text())
-		if dir is not None:
-			for directory in dir: # iterate over selected files
+		dir1 = ChooseDir(self.Main.get_toplevel(), self.IncompleteDir.get_text())
+		if dir1 is not None:
+			for directory in dir1: # iterate over selected files
 				self.incompletedir = directory
 				self.IncompleteDir.set_text(recode(directory))
 
 	def OnChooseDownloadDir(self, widget):
-		dir = ChooseDir(self.Main.get_toplevel(), self.DownloadDir.get_text())
-
-		if dir is not None:
-			for directory in dir: # iterate over selected files
+		dir1 = ChooseDir(self.Main.get_toplevel(), self.DownloadDir.get_text())
+		if dir1 is not None:
+			for directory in dir1: # iterate over selected files
 				self.DownloadDir.set_text(recode(directory))
 				if self.ShareDownloadDir.get_active():
 					self.needrescan = 1
@@ -247,7 +255,9 @@ class TransfersFrame(settings_glade.TransfersFrame):
 		self.OnQueueUseSlotsToggled(self.QueueUseSlots)
 		self.OnLimitToggled(self.Limit)
 		self.OnFriendsOnlyToggled(self.FriendsOnly)
-	
+		
+
+			
 	def GetSettings(self):
 		try:
 			uploadbandwidth = int(self.QueueBandwidth.get_text())
@@ -284,6 +294,7 @@ class TransfersFrame(settings_glade.TransfersFrame):
 				"preferfriends": self.PreferFriends.get_active(),
 				"lock": self.LockIncoming.get_active(),
 				"remotedownloads": self.RemoteDownloads.get_active(),
+				
 			},
 		}
 
@@ -352,28 +363,28 @@ class UserinfoFrame(settings_glade.UserinfoFrame):
 				"descrutf8": 1,
 			}
 		}
+
 		
 	def OnChooseImage(self, widget):
-		dlg = gtk.FileSelection()
-		dlg.set_filename(self.Image.get_text())
-		result = dlg.run()
-		if result == gtk.RESPONSE_OK:
-			self.Image.set_text(dlg.get_filename())
-		dlg.destroy()
+		dlg = ChooseImage(initialfile=self.Image.get_text())
+		if dlg:
+			for file in dlg:
+				self.Image.set_text(file)
+				break
 
 class BanFrame(settings_glade.BanFrame):
 	def __init__(self):
 		settings_glade.BanFrame.__init__(self, False)
 		self.banned = []
 		self.banlist = gtk.ListStore(gobject.TYPE_STRING)
-		column = gtk.TreeViewColumn("Users", gtk.CellRendererText(), text = 0)
+		column = gtk.TreeViewColumn(_("Users"), gtk.CellRendererText(), text = 0)
 		self.Banned.append_column(column)
 		self.Banned.set_model(self.banlist)
 		self.Banned.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
 
 		self.ignored = []
 		self.ignorelist = gtk.ListStore(gobject.TYPE_STRING)
-		column = gtk.TreeViewColumn("Users", gtk.CellRendererText(), text = 0)
+		column = gtk.TreeViewColumn(_("Users"), gtk.CellRendererText(), text = 0)
 		self.Ignored.append_column(column)
 		self.Ignored.set_model(self.ignorelist)
 		self.Ignored.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
@@ -411,7 +422,7 @@ class BanFrame(settings_glade.BanFrame):
 		}
 	
 	def OnAddBanned(self, widget):
-		user = InputDialog(self.Main.get_toplevel(), "Ban user...", "User:")
+		user = InputDialog(self.Main.get_toplevel(), _("Ban user..."), _("User:") )
 		if user and user not in self.banned:
 			self.banned.append(user)
 			self.banlist.append([user])
@@ -432,7 +443,7 @@ class BanFrame(settings_glade.BanFrame):
 		self.banlist.clear()
 
 	def OnAddIgnored(self, widget):
-		user = InputDialog(self.Main.get_toplevel(), "Ignore user...", "User:")
+		user = InputDialog(self.Main.get_toplevel(), _("Ignore user..."), _("User:") )
 		if user and user not in self.ignored:
 			self.ignored.append(user)
 			self.ignorelist.append([user])
@@ -457,9 +468,10 @@ class BloatFrame(settings_glade.BloatFrame):
 		settings_glade.BloatFrame.__init__(self, False)
 		for item in ["<None>", ",", ".", "<space>"]:
 			self.DecimalSep.append_text(item)
-		#self.font =""
+		for item in ["play -q", "ogg123 -q"]:
+			self.SoundCommand.append_text(item)
 		self.ThemeButton.connect("clicked", self.OnChooseThemeDir)
-		#self.SelectChatFont.connect("font-set", self.OnChooseChatFont)
+		self.SoundButton.connect("clicked", self.OnChooseSoundDir)
 		
 		self.PickRemote.connect("clicked", self.PickColour, self.Remote)
 		self.PickLocal.connect("clicked", self.PickColour, self.Local)
@@ -474,6 +486,8 @@ class BloatFrame(settings_glade.BloatFrame):
 		self.DefaultHighlight.connect("clicked", self.DefaultColour, self.Highlight)
 		self.DefaultImmediate.connect("clicked", self.DefaultColour, self.Immediate)
 		self.DefaultQueue.connect("clicked", self.DefaultColour, self.Queue)
+		self.DefaultQueue.connect("clicked", self.DefaultColour, self.Queue)
+		self.DefaultSoundCommand.connect("clicked", self.DefaultSound, self.SoundCommand)
 		
 	def OnChooseThemeDir(self, widget):
 		dir = ChooseDir(self.Main.get_toplevel(), self.IconTheme.get_text())
@@ -481,6 +495,12 @@ class BloatFrame(settings_glade.BloatFrame):
 			for directory in dir: # iterate over selected files
 				self.IconTheme.set_text(recode(directory))
 				
+	def OnChooseSoundDir(self, widget):
+		dir = ChooseDir(self.Main.get_toplevel(), self.SoundDirectory.get_text())
+		if dir is not None:
+			for directory in dir: # iterate over selected files
+				self.SoundDirectory.set_text(recode(directory))
+								
 	def SetSettings(self, config):
 		ui = config["ui"]
 		transfers = config["transfers"]
@@ -505,7 +525,19 @@ class BloatFrame(settings_glade.BloatFrame):
 			self.DecimalSep.child.set_text(ui["decimalsep"])
 		if ui["tabclosers"] is not None:
 			self.TabClosers.set_active(ui["tabclosers"])
-
+		#if sys.platform == "win32":
+		#	self.TrayiconCheck.set_sensitive(False)
+		if ui["trayicon"] is not None:
+			self.TrayiconCheck.set_active(ui["trayicon"])
+		if ui["soundenabled"] is not None:
+			self.SoundCheck.set_active(ui["soundenabled"])
+		self.OnSoundCheckToggled(self.SoundCheck)
+		if ui["soundcommand"] is not None:
+			self.SoundCommand.child.set_text(ui["soundcommand"])
+		if ui["soundtheme"] is not None:
+			self.SoundDirectory.set_text(ui["soundtheme"])
+		if transfers["enabletransferbuttons"] is not None:
+			self.ShowTransferButtons.set_active(transfers["enabletransferbuttons"])
 	def GetSettings(self):
 		return {
 			"ui": {
@@ -519,11 +551,27 @@ class BloatFrame(settings_glade.BloatFrame):
 				"searchq": self.Queue.get_text(),
 				"decimalsep": self.DecimalSep.child.get_text(),
 				"tabclosers": self.TabClosers.get_active(),
+				"trayicon": self.TrayiconCheck.get_active(),
+				"soundcommand": self.SoundCommand.child.get_text(),
+				"soundtheme": self.SoundDirectory.get_text(),
+				"soundenabled": self.SoundCheck.get_active(),
+			},
+			"transfers": {
+				"enabletransferbuttons": self.ShowTransferButtons.get_active(),
 			},
 		}
-	
+		
+	def OnSoundCheckToggled(self, widget):
+		sensitive = widget.get_active()
+		self.SoundCommand.set_sensitive(sensitive)
+		self.SoundDirectory.set_sensitive(sensitive)
+		self.SoundButton.set_sensitive(sensitive)
+		self.DefaultSoundCommand.set_sensitive(sensitive)
+		self.sndcmdLabel.set_sensitive(sensitive)
+		self.snddirLabel.set_sensitive(sensitive)
+		
 	def PickColour(self, widget, entry):
-		dlg = gtk.ColorSelectionDialog("Pick a colour, any colour")
+		dlg = gtk.ColorSelectionDialog(_("Pick a colour, any colour"))
 		colour = entry.get_text()
 		if colour != None and colour !='':
 			colour = gtk.gdk.color_parse(colour)
@@ -536,6 +584,9 @@ class BloatFrame(settings_glade.BloatFrame):
 		
 	def DefaultColour(self, widget, entry):
 		entry.set_text("")
+		
+	def DefaultSound(self, widget, combo):
+		combo.child.set_text("play -q")
 			
 class LogFrame(settings_glade.LogFrame):
 	def __init__(self):
@@ -767,9 +818,10 @@ class SettingsWindow(settings_glade.SettingsWindow):
 		gobject.signal_new("settings-closed", gtk.Window, gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, (gobject.TYPE_STRING,))
 		
 		self.SettingsWindow.set_transient_for(frame.MainWindow)
-
+		self.SettingsWindow.set_geometry_hints(None, min_width=550, min_height=400)
+		self.SettingsWindow.set_default_size(700, 500)
 		self.SettingsWindow.connect("delete-event", self.OnDelete)
-		
+		self.frame = frame
 		self.empty_label = gtk.Label("")
 		self.empty_label.show()
 		self.viewport1.add(self.empty_label)
