@@ -258,16 +258,23 @@ class RemoveUser(ServerMessage):
         return self.packObject(self.user)
 
 class GetUserStatus(ServerMessage):
-    """ Server tells us if a user has gone away or has returned"""
-    def __init__(self, user = None):
-        self.user = user
+	""" Server tells us if a user has gone away or has returned"""
+	def __init__(self, user = None):
+		self.user = user
+		self.privileged = None
 
-    def makeNetworkMessage(self):
-        return self.packObject(self.user)
+	def makeNetworkMessage(self):
+		return self.packObject(self.user)
 
-    def parseNetworkMessage(self,message):
-        len,self.user = self.getObject(message,types.StringType)
-        len,self.status = self.getObject(message, types.IntType,len)
+	def parseNetworkMessage(self,message):
+	
+		len,self.user = self.getObject(message,types.StringType)
+		len,self.status = self.getObject(message, types.IntType,len)
+		# Exception handler is for Soulfind compatibility
+		try:
+			len, self.privileged = len+1, ord(message[len])
+		except:
+			pass
 
 class SetStatus(ServerMessage):
     """ We send our new status to the server """
@@ -491,8 +498,8 @@ class QueuedDownloads(ServerMessage):
         len, self.slotsfull = self.getObject(message,types.IntType, len)
 
 class SendSpeed(ServerMessage):
-    """ We send this after a finished download to let the server update
-    the spped statistics for a user"""
+    """ We used to send this after a finished download to let the server update
+    the speed statistics for a user"""
     def __init__(self, user = None, speed = None):
 	self.user = user
 	self.speed = speed
@@ -500,6 +507,15 @@ class SendSpeed(ServerMessage):
     def makeNetworkMessage(self):
 	return self.packObject(self.user)+self.packObject(self.speed)
 
+class SendUploadSpeed(ServerMessage):
+    """ We now send this after a finished upload to let the server update
+    the spped statistics for a user"""
+    def __init__(self, speed = None):
+	self.speed = speed
+
+    def makeNetworkMessage(self):
+	return self.packObject(self.speed)
+    
 class SharedFoldersFiles(ServerMessage):
     """ We send this to server to indicate the number of folder and files
     that we share """
@@ -650,6 +666,18 @@ class MinParentsInCache(Msg83):
     pass
 class Msg12547(Msg83):
     pass
+
+class UploadQueueNotification(PeerMessage):
+    def __init__(self,conn):
+	self.conn = conn
+
+    def makeNetworkMessage(self):
+	return ""
+
+    def parseNetworkMessage(self, message):
+        return ""
+
+    
 class Msg89(Msg83):
     pass
 
@@ -1009,9 +1037,7 @@ class FileSearchResult(PeerMessage):
             print error
             self.list={}
             return
-#        f = open("ttt","w")
-#        f.write(message)
-#        f.close()
+
 	len, self.user = self.getObject(message,types.StringType)
 	len, self.token = self.getObject(message,types.IntType,len)
         len, nfiles = self.getObject(message,types.IntType, len)
@@ -1024,10 +1050,11 @@ class FileSearchResult(PeerMessage):
             len, ext = self.getObject(message,types.StringType, len)
             len, numattr = self.getObject(message, types.IntType, len)
             attrs = []
-            for j in range(numattr):
-                len, attrnum = self.getObject(message,types.IntType, len)
-                len, attr = self.getObject(message,types.IntType, len)
-                attrs.append(attr)
+            if numattr:
+		for j in range(numattr):
+			len, attrnum = self.getObject(message,types.IntType, len)
+			len, attr = self.getObject(message,types.IntType, len)
+			attrs.append(attr)
             list.append([code,name,size,ext,attrs])
         self.list = list
 	len, self.freeulslots = len+1, ord(message[len])
@@ -1041,16 +1068,7 @@ class FileSearchResult(PeerMessage):
 		filelist.append(self.fileindex[str(i)])
 	    except:
 		pass
-	#count = 0
-	#for i in filelist:
-	    #if i[0][-4:].lower() == ".ogg":
-		#count += 1
-	    #else:
-		#count -= 1
-	#if count > 0:
-	    #queuesize = self.inqueue[1]
-	#else:
-	    #queuesize = self.inqueue[0]
+
 	if self.fifoqueue:
 	    queuesize = self.inqueue[0]
 	else:
