@@ -94,13 +94,13 @@ class SlskProtoThread(threading.Thread):
                    ItemSimilarUsers:112,RoomTickerState:113,
                    RoomTickerAdd:114,RoomTickerRemove:115,
                    RoomTickerSet:116,AddThingIHate:117,RemoveThingIHate:118,
-                   RoomSearch:120,GivePrivileges:123}
+                   RoomSearch:120, SendUploadSpeed:121, GivePrivileges:123}
     peercodes = {GetSharedFileList:4, SharedFileList:5, FileSearchRequest:8,
 		FileSearchResult:9,
 		UserInfoRequest:15,UserInfoReply:16, FolderContentsRequest:36,
 		FolderContentsResponse:37, TransferRequest:40,
 		TransferResponse:41,PlaceholdUpload:42,QueueUpload:43,
-		PlaceInQueue:44,UploadFailed:46,QueueFailed:50,PlaceInQueueRequest:51, 
+		PlaceInQueue:44,UploadFailed:46,QueueFailed:50,PlaceInQueueRequest:51, UploadQueueNotification:52,
 		Msg12547:12547}
 
     distribclasses = {0:DistribAlive,3:DistribSearch}
@@ -272,19 +272,20 @@ class SlskProtoThread(threading.Thread):
                             del conns[i]
 
 # ---------------------------
-#	This Gets Nicotine users banned
+#	This sometimes(?) Gets Nicotine users banned
 # ---------------------------
-# 	    curtime = time.time()
-# 	    for i in conns.keys()[:]:
-# 		if i is not s:
-# 		    if curtime - conns[i].lastactive > 120:
-# 			self._ui_callback([ConnClose(i,conns[i].addr)])
-#                         i.close()
-#                         del conns[i]
-# 		else:
-# 		    if curtime - conns[s].lastping > 30:
-# 			conns[s].lastping = curtime
-# 			queue.put(ServerPing()) 
+	    curtime = time.time()
+	    for i in conns.keys()[:]:
+		if i is not s:
+		    if curtime - conns[i].lastactive > 120:
+			self._ui_callback([ConnClose(i,conns[i].addr)])
+                        i.close()
+                        del conns[i]
+		else:
+		    #  Was 30 seconds
+		    if curtime - conns[s].lastping > 120:
+			conns[s].lastping = curtime
+			queue.put(ServerPing()) 
 	    self._ui_callback([])
 	if s is not None:
             s.close()
